@@ -1,4 +1,4 @@
-from typing import TypedDict, Optional, Literal
+from typing import TypedDict, Optional, Literal, List
 
 from method.resource import Resource
 from method.configuration import Configuration
@@ -25,7 +25,8 @@ class Element(TypedDict):
 
 
 class ElementExchangePublicAccountOpts(TypedDict):
-    public_account_token: str
+    public_account_token: Optional[str]
+    public_account_tokens: Optional[List[str]]
 
 
 class ElementResource(Resource):
@@ -37,3 +38,6 @@ class ElementResource(Resource):
 
     def exchange_public_account_token(self, opts: ElementExchangePublicAccountOpts) -> Account:
         return super(ElementResource, self)._create_with_sub_path('/accounts/exchange', opts)
+
+    def exchange_public_account_tokens(self, opts: ElementExchangePublicAccountOpts) -> Account:
+        return super(ElementResource, self)._create_with_sub_path('/accounts/exchange', opts)
